Package: BGmisc
Title: An R Package for Extended Behavior Genetics Analysis
Version: 1.6.0.1
Authors@R: c(
    person("S. Mason", "Garrison", , "garrissm@wfu.edu", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-4804-6003")),
    person(c("Michael", "D."), "Hunter", role = "aut",
           comment = c(ORCID = "0000-0002-3651-6709")),
    person("Xuanyu", "Lyu", role = "aut",
           comment = c(ORCID = "0000-0002-2841-5529")),
    person(c("Rachel", "N."), "Good", role = "ctb"),
    person(c("Jonathan", "D."), "Trattner", , "code@jdtrat.com", role = "aut",
           comment = c(ORCID = "0000-0002-1097-7603")),
    person(c("S.", "Alexandra"), "Burt", role = "aut",
           comment = c(ORCID = "0000-0001-5538-7431"))
  )
Description: Provides functions for behavior genetics analysis, 
    including variance component model identification [Hunter et al. (2021) <doi:10.1007/s10519-021-10055-x>],
    calculation of relatedness coefficients using path-tracing methods 
    [Wright (1922) <doi:10.1086/279872>; McArdle & McDonald (1984) <doi:10.1111/j.2044-8317.1984.tb00802.x>], 
    inference of relatedness, pedigree conversion, and simulation of multi-generational family data 
    [Lyu et al. (2025) <doi:10.1007/s10519-025-10225-1>]. For a full overview, 
    see [Garrison et al. (2024) <doi:10.21105/joss.06203>]. For a big data application see [Burt et al. (2025) <doi: 10.1016/j.ebiom.2025.105911>.
License: GPL-3
URL: https://github.com/R-Computing-Lab/BGmisc/,
        https://r-computing-lab.github.io/BGmisc/
BugReports: https://github.com/R-Computing-Lab/BGmisc/issues
Depends: R (>= 3.5.0)
Imports: data.table, igraph, Matrix, stats, stringr, methods
Suggests: corrplot, discord, dplyr, EasyMx, ggpedigree, ggplot2,
        kinship2, knitr, OpenMx, rmarkdown, testthat (>= 3.0.0),
        tidyverse, mvtnorm, withr
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-03-13 16:25:30 UTC; smaso
Author: S. Mason Garrison [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-4804-6003>),
  Michael D. Hunter [aut] (ORCID:
    <https://orcid.org/0000-0002-3651-6709>),
  Xuanyu Lyu [aut] (ORCID: <https://orcid.org/0000-0002-2841-5529>),
  Rachel N. Good [ctb],
  Jonathan D. Trattner [aut] (ORCID:
    <https://orcid.org/0000-0002-1097-7603>),
  S. Alexandra Burt [aut] (ORCID:
    <https://orcid.org/0000-0001-5538-7431>)
Maintainer: S. Mason Garrison <garrissm@wfu.edu>
Repository: CRAN
Date/Publication: 2026-03-13 17:00:07 UTC
Built: R 4.6.0; ; 2026-04-27 23:36:37 UTC; unix
