# Generated by roxygen2: do not edit by hand

export(SimPed)
export(addPersonToPed)
export(buildFamilyGroups)
export(buildOneFamilyGroup)
export(buildPedigreeModelCovariance)
export(buildPedigreeMx)
export(buildTreeGrid)
export(calcAllGens)
export(calcFamilySize)
export(calculateCIs)
export(calculateRelatedness)
export(checkIDs)
export(checkParentIDs)
export(checkPedigreeNetwork)
export(checkSex)
export(com2links)
export(comp2vech)
export(computeParentAdjacency)
export(createGenDataFrame)
export(determineSex)
export(dropLink)
export(fitComponentModel)
export(fitPedigreeModel)
export(getWikiTreeSummary)
export(identifyComponentModel)
export(inferRelatedness)
export(makeInbreeding)
export(makeTwins)
export(ped2add)
export(ped2ce)
export(ped2cn)
export(ped2com)
export(ped2fam)
export(ped2gen)
export(ped2graph)
export(ped2maternal)
export(ped2mit)
export(ped2paternal)
export(readGed)
export(readGedcom)
export(readWikifamilytree)
export(readgedcom)
export(recodeSex)
export(related_coef)
export(repairIDs)
export(repairSex)
export(simulatePedigree)
export(sliceFamilies)
export(summariseFamilies)
export(summariseMatrilines)
export(summarisePatrilines)
export(summarisePedigrees)
export(summarizeFamilies)
export(summarizeMatrilines)
export(summarizePatrilines)
export(summarizePedigrees)
export(traceTreePaths)
export(vech)
importFrom(Matrix,Diagonal)
importFrom(Matrix,sparseMatrix)
importFrom(data.table,as.data.table)
importFrom(stats,na.omit)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,runif)
